@@ -4,6 +4,7 @@ from pymyorm.local import local
 class Model(object):
     tablename = None
     primary_key = 'id'
+    datetime_fields = []
 
     def __init__(self, **kwargs) -> None:
         self.__conn = local.conn
@@ -33,11 +34,15 @@ class Model(object):
 
     def __getattr__(self, name):
         if name in self.__new_fields:
-            return self.__new_fields[name]
+            value = self.__new_fields[name]
         elif name in self.__old_fields:
-            return self.__old_fields[name]
+            value = self.__old_fields[name]
         else:
             raise Exception(f"object has no attribute '{name}'")
+        if name in self.datetime_fields:
+            return value.strftime('%Y-%m-%d %H:%M:%S')
+        else:
+            return value
 
     def __getitem__(self, item):
         return getattr(self, item)
@@ -251,15 +256,21 @@ class Model(object):
             if len(args) != 3:
                 raise Exception('where statement error')
             field = args[0]
+            value = args[2]
+            if value == '' or value is None:
+                return self
+
             if field.find('.'):
                 field = '.'.join([f"`{v}`" for v in field.split('.')])
             cond = dict()
             cond['op'] = args[1]
             cond['field'] = field
-            cond['value'] = args[2]
+            cond['value'] = value
             self.__where.append(cond)
         if len(kwargs) > 0:
             for k, v in kwargs.items():
+                if v == '' or v is None:
+                    continue
                 cond = dict()
                 cond['op'] = '='
                 cond['field'] = f"`{k}`"
